quantizationtools.GraceHandler
==============================

.. abjad-lineage:: abjad.tools.quantizationtools.GraceHandler.GraceHandler.GraceHandler

.. autoclass:: abjad.tools.quantizationtools.GraceHandler.GraceHandler.GraceHandler
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.GraceHandler.GraceHandler.GraceHandler.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.GraceHandler.GraceHandler.GraceHandler.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.GraceHandler.GraceHandler.GraceHandler.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.GraceHandler.GraceHandler.GraceHandler.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.GraceHandler.GraceHandler.GraceHandler.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.GraceHandler.GraceHandler.GraceHandler.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.GraceHandler.GraceHandler.GraceHandler.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.GraceHandler.GraceHandler.GraceHandler.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.GraceHandler.GraceHandler.GraceHandler.__repr__
   :noindex:
